@@ -2,7 +2,9 @@
 """Checker of PEP-8 Naming Conventions."""
 import sys
 from collections import deque
+from fnmatch import fnmatch
 from functools import partial
+from itertools import chain
 
 from flake8_polyfill import options
 
@@ -12,7 +14,7 @@ try:
 except ImportError:
     from flake8.util import ast, iter_child_nodes
 
-__version__ = '0.9.1'
+__version__ = '0.10.0'
 
 PYTHON_VERSION = sys.version_info[:3]
 PY2 = PYTHON_VERSION[0] == 2
@@ -78,6 +80,10 @@ def _err(self, node, code, **kwargs):
     return lineno, col_offset + 1, '%s %s' % (code, code_str), self
 
 
+def _ignored(name, ignore):
+    return any(fnmatch(name, i) for i in ignore)
+
+
 BaseASTCheck = _ASTCheckMeta('BaseASTCheck', (object,),
                              {'__doc__': "Base for AST Checks.", 'err': _err})
 
@@ -132,8 +138,8 @@ class NamingChecker(object):
                          type='string',
                          parse_from_config=True,
                          comma_separated_list=True,
-                         help='List of names the pep8-naming plugin should '
-                              'ignore. (Defaults to %default)')
+                         help='List of names or glob patterns the pep8-naming '
+                              'plugin should ignore. (Defaults to %default)')
 
         options.register(parser, '--classmethod-decorators',
                          default=_default_classmethod_decorators,
@@ -207,11 +213,15 @@ class NamingChecker(object):
             if isinstance(meth, ast.Name):
                 late_decoration[meth.id] = self.decorator_to_type[func_name]
 
-        cls_bases = [b for b in cls_node.bases if isinstance(b, ast.Name)]
-        # If this class inherits from `type`, it's a metaclass, and we'll
-        # consider all of it's methods to be classmethods.
-        ismetaclass = any(
-            name for name in cls_bases if name.id in METACLASS_BASES)
+        # If this class inherits from a known metaclass base class, it is
+        # itself a metaclass, and we'll consider all of it's methods to be
+        # classmethods.
+        bases = chain(
+            (b.id for b in cls_node.bases if isinstance(b, ast.Name)),
+            (b.attr for b in cls_node.bases if isinstance(b, ast.Attribute)),
+        )
+        ismetaclass = any(name for name in bases if name in METACLASS_BASES)
+
         self.set_function_nodes_types(
             iter_child_nodes(cls_node), ismetaclass, late_decoration)
 
@@ -260,7 +270,7 @@ class ClassNameCheck(BaseASTCheck):
 
     def visit_classdef(self, node, parents, ignore=None):
         name = node.name
-        if ignore and name in ignore:
+        if _ignored(name, ignore):
             return
         name = name.strip('_')
         if not name[:1].isupper() or '_' in name:
@@ -283,7 +293,7 @@ class FunctionNameCheck(BaseASTCheck):
     def visit_functiondef(self, node, parents, ignore=None):
         function_type = getattr(node, 'function_type', _FunctionType.FUNCTION)
         name = node.name
-        if ignore and name in ignore:
+        if _ignored(name, ignore):
             return
         if name in ('__dir__', '__getattr__'):
             return
@@ -317,9 +327,9 @@ class FunctionArgNamesCheck(BaseASTCheck):
                 return node, arg
 
         for arg, name in arg_name(node.args.vararg), arg_name(node.args.kwarg):
-            if name in ignore:
-               continue
-            if name is not None and name.lower() != name:
+            if name is None or _ignored(name, ignore):
+                continue
+            if name.lower() != name:
                 yield self.err(arg, 'N803', name=name)
                 return
 
@@ -330,13 +340,13 @@ class FunctionArgNamesCheck(BaseASTCheck):
         function_type = getattr(node, 'function_type', _FunctionType.FUNCTION)
 
         if function_type == _FunctionType.METHOD:
-            if name0 != 'self':
+            if name0 != 'self' and not _ignored(name0, ignore):
                 yield self.err(arg0, 'N805')
         elif function_type == _FunctionType.CLASSMETHOD:
-            if name0 != 'cls':
+            if name0 != 'cls' and not _ignored(name0, ignore):
                 yield self.err(arg0, 'N804')
         for arg, name in arg_name_tuples:
-            if name.lower() != name and name not in ignore:
+            if name.lower() != name and not _ignored(name, ignore):
                 yield self.err(arg, 'N803', name=name)
                 return
 
@@ -351,6 +361,7 @@ class ImportAsCheck(BaseASTCheck):
     N812 = "lowercase '{name}' imported as non lowercase '{asname}'"
     N813 = "camelcase '{name}' imported as lowercase '{asname}'"
     N814 = "camelcase '{name}' imported as constant '{asname}'"
+    N817 = "camelcase '{name}' imported as acronym '{asname}'"
 
     def visit_importfrom(self, node, parents, ignore=None):
         for name in node.names:
@@ -368,7 +379,10 @@ class ImportAsCheck(BaseASTCheck):
             elif asname.islower():
                 yield self.err(node, 'N813', **err_kwargs)
             elif asname.isupper():
-                yield self.err(node, 'N814', **err_kwargs)
+                if ''.join(filter(str.isupper, original_name)) == asname:
+                    yield self.err(node, 'N817', **err_kwargs)
+                else:
+                    yield self.err(node, 'N814', **err_kwargs)
 
     visit_import = visit_importfrom
 
@@ -392,24 +406,38 @@ class VariablesCheck(BaseASTCheck):
         else:
             checker = self.global_variable_check
         for name in _extract_names(assignment_target):
-            if name in ignore:
+            if _ignored(name, ignore):
                 continue
             error_code = checker(name)
             if error_code:
                 yield self.err(assignment_target, error_code, name=name)
 
+    @staticmethod
+    def is_namedtupe(node_value):
+        if isinstance(node_value, ast.Call):
+            if isinstance(node_value.func, ast.Attribute):
+                if node_value.func.attr == 'namedtuple':
+                    return True
+            elif isinstance(node_value.func, ast.Name):
+                if node_value.func.id == 'namedtuple':
+                    return True
+        return False
+
     def visit_assign(self, node, parents, ignore=None):
-        if isinstance(node.value, ast.Call):
-            if isinstance(node.value.func, ast.Attribute):
-                if node.value.func.attr == 'namedtuple':
-                    return
-            elif isinstance(node.value.func, ast.Name):
-                if node.value.func.id == 'namedtuple':
-                    return
+        if self.is_namedtupe(node.value):
+            return
         for target in node.targets:
             for error in self._find_errors(target, parents, ignore):
                 yield error
 
+    def visit_namedexpr(self, node, parents, ignore):
+        if self.is_namedtupe(node.value):
+            return
+        for error in self._find_errors(node.target, parents, ignore):
+            yield error
+
+    visit_annassign = visit_namedexpr
+
     def visit_with(self, node, parents, ignore):
         if PY2:
             for error in self._find_errors(
