@@ -20,6 +20,9 @@ def _go_od_():
 def NotOK():
     pass
 #: Okay(--ignore-names=NotOK)
+def NotOK():
+    pass
+#: Okay(--ignore-names=*OK)
 def NotOK():
     pass
 #: Okay
@@ -42,6 +45,10 @@ class ClassName(object):
     def notOk(self):
         pass
 #: Okay(--ignore-names=notOk)
+class ClassName(object):
+    def notOk(self):
+        pass
+#: Okay(--ignore-names=*Ok)
 class ClassName(object):
     def notOk(self):
         pass
